#-----------------------------------------------------------------------------#
#         Statistical Inference: practical session  1                         #
# Evaluating properties of maximum likelihood estimates (MLEs) of $R0$ using  #
# simulated epidemic data from stochastic SIR models                          #
#-----------------------------------------------------------------------------#

myfolder <- "C:\\TutorialFolder"

#------------------------------------------------------------------------------#
#   Step 1: Initial setup, generating stochastic SIR data and calculating      #
#   MLE estimates  for sample size 25                                          #
#                                                                              #
#------------------------------------------------------------------------------#
setwd(myfolder)
source("cplot.R") ; source("MLEforSIR.R")
source("stochasticSIRmodel.R")
#------------------------------------------------------------------------------#
#                             parameters                                       #
#------------------------------------------------------------------------------#
Nvec <- c(25, 50, 100)       # sample sizes for each of the three scenarios
reps <- 30                  # number of replicates
R0 <- 2                      #true value of R0
RRgamma <- 0.05              # recovery rate (RR)gamma
TRbeta <- R0*RRgamma         # transmission rate (TR) beta


# creating list to store R0 estimates for each scenario
# each element of the list is a data frame with maximum likelihood estimates
# and confidence interval for each replicate

R0est <- list()
R0est[[1]] <- R0est[[2]] <- R0est[[3]] <- matrix(0,nr=reps, nc=4)



# generating the data
source("stochasticSIRmodel.R")
SIRdata25 <- SIRdataGen(nReps=reps,TRbeta=TRbeta, RRgamma=RRgamma,
                        genArc="noVar", N=Nvec[1], ngroups=1)

# calculating maximum likelihood estimates for each replicate
for (i in 1:reps)  R0est[[1]][i,1:3] <- mleSIR(SIRdata25[[i]])

# Plotting MLE estimates (point estimates and confidence intervals)

par(mfrow=c(1,1))
ttl<-"maximum likelihood estimates for R0 \n N=25 - 30 replicates (NO individual heterogeneity)"
centipedePlot(t(R0est[[1]]),left.labels=" ",right.labels=" ",sort.segs=T,mar=c(4,.5,3,4),gridcol=c("red","blue"),  vgrid=c(1,R0), xlim=c(0,6),lty=1,
   main=ttl,xlab="")
legend(3,11,c("R0=1","true R0"),col=c("red","blue"),lty=1,bty="n",cex=1.5)
legend(3.2,14,c("point estimate"), bty="n",cex=1.5,pch=19,col="green")
legend(3,12.5,c("90% confidence interval"),col="black", bty="n",cex=1.5,lty=1)


#------------------------------------------------------------------------------#
#            Step 3: Generating stochastic SIR data and calculating            #
#                    MLE estimates  - sample size 50 and 100                   #
#------------------------------------------------------------------------------#
# generating the data
SIRdata50 <- SIRdataGen(nReps=reps,TRbeta=TRbeta, RRgamma=RRgamma,
                        genArc="noVar", N=Nvec[2], ngroups=1)

SIRdata100 <- SIRdataGen(nReps=reps,TRbeta=TRbeta, RRgamma=RRgamma,
                        genArc="noVar", N=Nvec[3], ngroups=1)

# calculating maximum likelihood estimates for all simulated data
for (i in 1:reps){
  R0est[[2]][i,1:3] <- mleSIR(SIRdata50[[i]])
  R0est[[3]][i,1:3] <- mleSIR(SIRdata100[[i]])
}



# comparing estimates from different sample sizes
par(mfrow=c(2,3))
#plotting again for size 25
ttl<-"maximum likelihood estimates for R0 \n N=25 - 30 replicates (NO individual heterogeneity)"
centipedePlot(t(R0est[[1]]),left.labels=" ",right.labels=" ",sort.segs=T,mar=c(4,.5,3,4),gridcol=c("red","blue"),  vgrid=c(1,R0), xlim=c(0,6),lty=2,
   main=ttl,xlab="")

#size 50
ttl<-"maximum likelihood estimates for R0 \n  N=50 - 30 replicates (NO individual heterogeneity)"
centipedePlot(t(R0est[[2]]),left.labels=" ",right.labels=" ",sort.segs=T,mar=c(4,.5,3,4),gridcol=c("red","blue"),  vgrid=c(1,R0), xlim=c(0,6),lty=2,
   main=ttl,xlab="")
#size 100
ttl<-"maximum likelihood estimates for R0 \n N=100 - 30 replicates (NO individual heterogeneity)"
centipedePlot(t(R0est[[3]]),left.labels=" ",right.labels=" ",sort.segs=T,mar=c(4,.5,3,4),gridcol=c("red","blue"),  vgrid=c(1,R0), xlim=c(0,6),lty=2,
   main=ttl,xlab="")
legend(2.3,9,c("R0=1","true R0"),col=c("red","blue"),lty=1,bty="n",cex=1.2)
legend(2.5,13,c("point estimate"),pch=19,col="green", bty="n",cex=1.2)
legend(2.3,11,c("90%  confidence int."),col="black", bty="n",cex=1.2,lty=1)

#------------------------------------------------------------------------------#
#    Step 4: Generating stochastic SIR data with individual variation          #
#     and calculating  MLE estimates  - sample sizes 25, 50 and 100             #              #------------------------------------------------------------------------------#
# generating the data for sample sizes 25, 50 and 100
SIRdata25Gvar <- SIRdataGen(nReps=reps,TRbeta=TRbeta, RRgamma=RRgamma,
                        genArc="GVar", ngroups=1,
                        SigG.g=0.5, SigG.f=0.5, SigE.g=0.5, SigE.f=0.5,
                        sires=5, dpsire=5)

SIRdata50Gvar <- SIRdataGen(nReps=reps,TRbeta=TRbeta, RRgamma=RRgamma,
                        genArc="GVar", ngroups=1,
                        SigG.g=0.5, SigG.f=0.5, SigE.g=0.5, SigE.f=0.5,
                        sires=5, dpsire=10)

SIRdata100Gvar <- SIRdataGen(nReps=reps,TRbeta=TRbeta, RRgamma=RRgamma,
                        genArc="GVar", ngroups=1,
                        SigG.g=0.5, SigG.f=0.5, SigE.g=0.5, SigE.f=0.5,
                        sires=5, dpsire=20)

# creating list to store R0 estimates for each scenario
# each element of the list is a data frame with maximum likelihood estimates
# and confidence interval for each replicate

R0estGvar <- list()
R0estGvar[[1]] <- R0estGvar[[2]] <- R0estGvar[[3]] <- matrix(0,nr=reps, nc=4)


# calculating maximum likelihood estimates for all simulated data
for (i in 1:reps){
  R0estGvar[[1]][i,1:3] <- mleSIR(SIRdata25Gvar[[i]])
  R0estGvar[[2]][i,1:3] <- mleSIR(SIRdata50Gvar[[i]])
  R0estGvar[[3]][i,1:3] <- mleSIR(SIRdata100Gvar[[i]])
}


# Plotting point estimates and confidence intervals for each scenario/replicate


#size 25
ttl<-"maximum likelihood estimates for R0 \n N=25 - 30 replicates (individual heterogeneity)"
centipedePlot(t(R0estGvar[[1]]),left.labels=" ",right.labels=" ",sort.segs=T,mar=c(4,.5,3,4),gridcol=c("red","blue"),  vgrid=c(1,R0), xlim=c(0,6),lty=2,
   main=ttl,xlab="")
#legend(3,10,c("R0=1","true R0"),col=c("red","blue"),lty=1,bty="n",cex=1.5)
#legend(3.5,12,c("point estimate"),pch=19,col="green", bty="n",cex=1.5)
#size 50
ttl<-"maximum likelihood estimates for R0 \n N=50 - 30 replicates (individual heterogeneity) "
centipedePlot(t(R0estGvar[[2]]),left.labels=" ",right.labels=" ",sort.segs=T,mar=c(4,.5,3,4),gridcol=c("red","blue"),  vgrid=c(1,R0), xlim=c(0,6),lty=2,
   main=ttl,xlab="")
#size 100
ttl<-"maximum likelihood estimates for R0 \n N=100 - 30 replicates (individual heterogeneity)"
centipedePlot(t(R0estGvar[[3]]),left.labels=" ",right.labels=" ",sort.segs=T,mar=c(4,.5,3,4),gridcol=c("red","blue"),  vgrid=c(1,R0), xlim=c(0,6),lty=2,
   main=ttl,xlab="")
